<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <location filename="../src/countdown_tooltip.cpp" line="78"/>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>点击托盘图标以停止录制
或再次按下深度录屏快捷键</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="76"/>
        <source>Deepin screen recorder</source>
        <translation>深度录屏</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="136"/>
        <source>Start recording</source>
        <translation>开始录制</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="454"/>
        <source>Select area</source>
        <translation>选择区域</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <location filename="../src/record_process.cpp" line="229"/>
        <source>deepin-screen-recorder</source>
        <translation>深度录屏</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="291"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="301"/>
        <source>Recording finished</source>
        <translation>录制完毕</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="302"/>
        <source>Saved to</source>
        <translation>保存在</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <location filename="../src/start_tooltip.cpp" line="48"/>
        <source>Click or drag to
select the area to record</source>
        <translation>点击或拖拽来选择录制区域</translation>
    </message>
</context>
</TS>